﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Syncfusion.SfSchedule.XForms;
using Xamarin.Forms;

namespace Sample
{
    public partial class MainPage : ContentPage
    {
        ScheduleViewModel viewModel;
        public MainPage()
        {
            InitializeComponent();

            DayViewSettings dayViewSettings = new DayViewSettings();
            dayViewSettings.WorkStartHour = 10;
            dayViewSettings.WorkEndHour = 15;
            dayViewSettings.TimeSlotColor = Color.White;
            dayViewSettings.TimeSlotBorderColor = Color.Gray;
            dayViewSettings.NonWorkingHoursTimeSlotColor = Color.Gray;
            dayViewSettings.NonWorkingHoursTimeSlotBorderColor = Color.Blue;
            schedule.DayViewSettings = dayViewSettings;

            WeekViewSettings weekViewSettings = new WeekViewSettings();
            weekViewSettings.WorkStartHour = 11;
            weekViewSettings.WorkEndHour = 16;
            weekViewSettings.TimeSlotColor = Color.Transparent;
            weekViewSettings.TimeSlotBorderColor = Color.Blue;
            weekViewSettings.NonWorkingHoursTimeSlotColor = Color.Yellow;
            weekViewSettings.NonWorkingHoursTimeSlotBorderColor = Color.Accent;
            schedule.WeekViewSettings = weekViewSettings;

            WorkWeekViewSettings workWeekViewSettings = new WorkWeekViewSettings();
            workWeekViewSettings.WorkStartHour = 12;
            workWeekViewSettings.WorkEndHour = 15;
            workWeekViewSettings.TimeSlotColor = Color.Accent;
            workWeekViewSettings.TimeSlotBorderColor = Color.Black;
            workWeekViewSettings.NonWorkingHoursTimeSlotColor = Color.Purple;
            workWeekViewSettings.NonWorkingHoursTimeSlotBorderColor = Color.Green;
            schedule.WorkWeekViewSettings = workWeekViewSettings;

            viewModel = new ScheduleViewModel();
            schedule.DataSource = viewModel.Appointments;

            schedule.AppointmentViewLayout = ViewLayoutOptions.Overlay;
            HookEvents();
        }

        private void HookEvents()
        {
            this.setPicker();
            schedule.OnAppointmentLoadedEvent += Schedule_OnAppointmentLoadedEvent;
            schedule.CellTapped += Schedule_CellTapped;
            schedule.OnMonthInlineAppointmentLoadedEvent += Schedule_OnMonthInlineAppointmentLoadedEvent;
        }

        void Schedule_OnMonthInlineAppointmentLoadedEvent(object sender, MonthInlineAppointmentLoadedEventArgs e)
        {
            Button button = new Button();
            button.Text = (e.appointment as ScheduleAppointment).Subject;
            button.BackgroundColor = Color.Blue;
            button.TextColor = Color.White;
            e.view = button;
        }

        void Schedule_CellTapped(object sender, CellTappedEventArgs e)
        {
            var appointment = e.Appointment;
            var DateTime = e.Datetime;
        }

        void Schedule_OnAppointmentLoadedEvent(object sender, AppointmentLoadedEventArgs e)
        {
            AppointmentStyle appoinmentStyle = new AppointmentStyle();
            appoinmentStyle.TextColor = Color.Transparent;
            appoinmentStyle.SelectionTextColor = Color.Transparent;
            e.appointmentStyle = appoinmentStyle;

            Button button = new Button();
            button.Text = (e.appointment as ScheduleAppointment).Subject;
            button.BackgroundColor = Color.Blue;
            button.TextColor = Color.White;
            e.view = button;
        }
        private void setPicker()
        {
            scheduleType.Items.Add("DayView");
            scheduleType.Items.Add("WeekView");
            scheduleType.Items.Add("WorkWeekView");
            scheduleType.Items.Add("MonthView");
            scheduleType.SelectedIndex = 0;
            scheduleType.SelectedIndexChanged += ScheduleType_SelectedIndexChanged;
        }
        private void ScheduleType_SelectedIndexChanged(object sender, EventArgs e)
        {
            if (((Picker)sender).SelectedIndex == 0)
                schedule.ScheduleView = ScheduleView.DayView;
            if (((Picker)sender).SelectedIndex == 1)
                schedule.ScheduleView = ScheduleView.WeekView;
            if (((Picker)sender).SelectedIndex == 2)
                schedule.ScheduleView = ScheduleView.WorkWeekView;
            if (((Picker)sender).SelectedIndex == 3)
                schedule.ScheduleView = ScheduleView.MonthView;
        }
    }
}
